@@ -4,21 +4,26 @@ package MooseX::Extended;
 
 use 5.20.0;
 use warnings;
-use feature qw(signatures);
 
 use Moose::Exporter;
 use Moose                     ();
 use MooseX::StrictConstructor ();
 use mro                       ();
 use namespace::autoclean      ();
-use MooseX::Extended::Core qw(field param);
+use MooseX::Extended::Core qw(
+  field
+  param
+  _enabled_features
+  _disabled_warnings
+);
+use feature _enabled_features();
 use B::Hooks::AtRuntime 'after_runtime';
 use Import::Into;
 
-no warnings qw(experimental::signatures experimental::postderef);
+no warnings _disabled_warnings();
 use true;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 Moose::Exporter->setup_import_methods(
     with_meta => [ 'field', 'param' ],
@@ -33,19 +38,15 @@ sub init_meta ( $class, %params ) {
     Moose->init_meta(%params);
     MooseX::StrictConstructor->import( { into => $for_class } );
     Carp->import::into($for_class);
-    feature->import(qw/signatures postderef :5.20/);
-    warnings->unimport(qw/experimental::postderef experimental::signatures/);
+    feature->import( _enabled_features() );
+    warnings->unimport(_disabled_warnings);
+    namespace::autoclean->import::into($for_class);
 
     # see perldoc -v '$^P'
     if ($^P) {
         say STDERR "We are running under the debugger. $for_class is not immutable";
     }
     else {
-        # we also remove namespace::autoclean because when those symbols get
-        # removed from the symbol table, you can't access them under the
-        # debugger! Very frustrating
-        namespace::autoclean->import::into($for_class);
-
         # after_runtime is loaded too late under the debugger
         after_runtime { $for_class->meta->make_immutable };
     }
@@ -69,7 +70,7 @@ MooseX::Extended - Extend Moose with safe defaults and useful features
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -106,7 +107,7 @@ version 0.02
 
 =head1 DESCRIPTION
 
-This module is B<EXPERIMENTAL>! All features subject to change.
+This module is B<ALPHA> code.
 
 This class attempts to create a safer version of Moose that defaults to
 read-only attributes and is easier to read and write.
@@ -129,7 +130,7 @@ Is sort of the equivalent to:
         use v5.20.0;
         use Moose;
         use MooseX::StrictConstructor;
-        use feature qw( signatures postderef );
+        use feature qw( signatures postderef postderef_qq);
         no warnings qw( experimental::signatures experimental::postderef );
         use namespace::autoclean;
         use Carp;
@@ -149,11 +150,11 @@ allowed to be passed to the constructor.
 
 Note that the C<has> function is still available, even if it's not needed.
 
-=head1 Immutability
+=head1 IMMUTABILITY
 
 =head2 Making Your Class Immutable
 
-Typically Moose classes should end with this:
+You no longer need to end your Moose classes with:
 
     __PACKAGE__->meta->make_immutable;
 
@@ -161,7 +162,7 @@ That prevents further changes to the class and provides some optimizations to
 make the code run much faster. However, it's somewhat annoying to type. We do
 this for you, via C<B::Hooks::AtRuntime>. You no longer need to do this yourself.
 
-=head2 Immutable Objects
+=head2 Making Your Instance Immutable
 
 By default, attributes defined via C<param> and C<field> are read-only.
 However, if they contain a reference, you can fetch the reference, mutate it,
@@ -175,7 +176,7 @@ See the L<MooseX::Extended::Manual::Cloning> documentation.
 
 Objection construction for L<MooseX::Extended> is like Moose, so no
 changes are needed.  However, in addition to C<has>, we also provide C<param>
-and C<field> attributes, both of which are C<< is => 'ro >> by default.
+and C<field> attributes, both of which are C<< is => 'ro' >> by default.
 
 The C<param> is I<required>, whether by passing it to the constructor, or using
 C<default> or C<builder>.
@@ -261,20 +262,16 @@ relies on L<B::Hooks::AtRuntime>'s C<after_runtime> function. However, that
 runs too late under the debugger and dies. Thus, we disable this feature under
 the debugger. Your classes may run a bit slower, but hey, it's the debugger!
 
-=item * No C<namespace::autoclean>
+=item * C<namespace::autoclean> will frustrate you
 
-It's very frustratting when running under the debugger and doing this:
+It's very frustrating when running under the debugger and doing this:
 
-  DB<4>
 	13==>       my $total = sum(3,4,5);
 	DB<4>
 	Undefined subroutine &main::sum called at (eval 423) ...
 
-You can I<see> the function defined there, so we can't you call it? Quite
-often, that's because L<namespace::autoclean> or L<namespace::clean> has been
-used, removing the symbol from the namespace, even though the subroutines are
-already bound in the code. Thus, if you're running under the debugger, we
-disable C<namespace::autoclean> to make the code easier to debug.
+We had removed C<namespace::autoclean> when running under the debugger, but
+backed that out: L<https://github.com/Ovid/moosex-extreme/issues/11>.
 
 =back
 
@@ -355,12 +352,8 @@ There are a few things you might be interested to know about this module when
 evaluating it.
 
 Most of this is written with bog-standard L<Moose>, so there's nothing
-terribly weird inside. However, there are a couple of modules which stand out.
-
-We do not need C<< __PACKAGE__->meta->make_immutable >> because we use
-L<B::Hooks::AtRuntime>'s C<after_runtime> function to set it.
-
-We do not need a true value at the end of a module because we use L<true>.
+terribly weird inside, but you may wish to note that we use
+L<B::Hooks::AtRuntime> and L<true>. They seem sane, but I<caveat emptor>.
 
 This module was originally released on github as C<MooseX::Extreme>, but
 enough people pointed out that it was not extreme at all. That's why the
