@@ -16,9 +16,17 @@ use Ref::Util qw(
 );
 use Carp 'croak';
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
-our @EXPORT_OK = qw(field param);
+our @EXPORT_OK = qw(
+  field
+  param
+  _enabled_features
+  _disabled_warnings
+);
+
+sub _enabled_features  {qw/signatures postderef postderef_qq :5.20/}             # internal use only
+sub _disabled_warnings {qw/experimental::signatures experimental::postderef/}    # internal use only
 
 sub param ( $meta, $name, %opt_for ) {
     $opt_for{is}       //= 'ro';
@@ -208,7 +216,7 @@ MooseX::Extended::Core - Internal module for MooseX::Extended
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 DESCRIPTION
 
